package com.hzya.frame.grpU8.nxproof.pubzyxx.dao.impl;

import com.baomidou.dynamic.datasource.annotation.DS;
import com.hzya.frame.basedao.dao.MybatisGenericDao;
import com.hzya.frame.grpU8.nxproof.pubzyxx.dao.ISenderPubzyxxDao;
import com.hzya.frame.grpU8.nxproof.pubzyxx.entity.SenderPubzyxxEntity;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * (Pubzyxx)表数据库访问层
 *
 * @author makejava
 * @since 2024-06-28 17:11:01
 */
@Repository(value = "SenderPubzyxxDaoImpl")
public class SenderPubzyxxDaoImpl extends MybatisGenericDao<SenderPubzyxxEntity, String> implements ISenderPubzyxxDao {


    @Override
    @DS("#senderPubzyxxEntity.dataSourceCode")
    public List<SenderPubzyxxEntity> querySenderPubzyxxEntity(SenderPubzyxxEntity senderPubzyxxEntity) {
        return super.queryByLike(senderPubzyxxEntity);
    }
    @Override
    @DS("#senderPubzyxxEntity.dataSourceCode")
    public SenderPubzyxxEntity saveSenderPubzyxxEntity(SenderPubzyxxEntity senderPubzyxxEntity) {
        return super.save(senderPubzyxxEntity);
    }
    @Override
    @DS("#senderPubzyxxEntity.dataSourceCode")
    public SenderPubzyxxEntity updateSenderPubzyxxEntity(SenderPubzyxxEntity senderPubzyxxEntity) {
        return super.update(senderPubzyxxEntity);
    }

    @Override
    @DS("#senderPubzyxxEntity.dataSourceCode")
    public List<SenderPubzyxxEntity> queryPubzyxxHealthBureau(SenderPubzyxxEntity senderPubzyxxEntity) {
        return super.query(senderPubzyxxEntity);
    }

    @Override
    @DS("#senderPubzyxxEntity.dataSourceCode")
    public SenderPubzyxxEntity savePubzyxxHealthBureau(SenderPubzyxxEntity senderPubzyxxEntity) {
        return super.save(senderPubzyxxEntity);
    }

    @Override
    @DS("#senderPubzyxxEntity.dataSourceCode")
    public SenderPubzyxxEntity updatePubzyxxHealthBureau(SenderPubzyxxEntity senderPubzyxxEntity) {
        return super.update(senderPubzyxxEntity);
    }

    @Override
    @DS("#senderPubzyxxEntity.dataSourceCode")
    public Integer deletePubzyxxHealthBureau(SenderPubzyxxEntity senderPubzyxxEntity) {
        return super.delete("SenderPubzyxxEntity_delete_zyxx",senderPubzyxxEntity);
    }
}

